"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ...models.components import configuration as components_configuration
from enum import Enum
from typing import List, Optional

class Type(str, Enum):
    r"""Configuration type - \\"LLM\\" or \\"pipeline\\" """
    LLM = 'LLM'
    PIPELINE = 'pipeline'


@dataclasses.dataclass
class GetConfigurationsRequest:
    project_name: str = dataclasses.field(metadata={'query_param': { 'field_name': 'project_name', 'style': 'form', 'explode': True }})
    r"""Project name for configuration"""
    type: Type = dataclasses.field(metadata={'query_param': { 'field_name': 'type', 'style': 'form', 'explode': True }})
    r"""Configuration type - \\"LLM\\" or \\"pipeline\\" """
    



@dataclasses.dataclass
class GetConfigurationsResponse:
    content_type: str = dataclasses.field()
    r"""HTTP response content type for this operation"""
    status_code: int = dataclasses.field()
    r"""HTTP response status code for this operation"""
    raw_response: requests_http.Response = dataclasses.field()
    r"""Raw HTTP response; suitable for custom response parsing"""
    configurations: Optional[List[components_configuration.Configuration]] = dataclasses.field(default=None)
    r"""An array of configurations"""
    

